"""
Licensed to the OpenAirInterface (OAI) Software Alliance under one or more
contributor license agreements.  See the NOTICE file distributed with
this work for additional information regarding copyright ownership.
The OpenAirInterface Software Alliance licenses this file to You under
the OAI Public License, Version 1.1  (the "License"); you may not use this file
except in compliance with the License.
You may obtain a copy of the License at

      http://www.openairinterface.org/?page_id=698

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
------------------------------------------------------------------------------
For more information about the OpenAirInterface (OAI) Software Alliance:
      contact@openairinterface.org
"""

import argparse
import logging
import os
import re
import sys
import subprocess

logging.basicConfig(
    level=logging.DEBUG,
    format="[%(asctime)s] %(name)s:%(levelname)s: %(message)s"
)

def main() -> None:
    """Provide command-line options to deploy a simple sanity check"""
    args = _parse_args()

    if args.mode == 'Deploy':
        deployObject(args.service, args.upf_tag)

    if args.mode == 'Check':
        logging.info ('Performing Check')
    if args.mode == 'UnDeploy':
        logging.info ('Un-Deploying ' + args.service)

def _parse_args() -> argparse.Namespace:
    """Parse the command line args

    Returns:
        argparse.Namespace: the created parser
    """
    parser = argparse.ArgumentParser(description='OAI UPF-VPP Sanity Check Deployment for CI')

    # Service to deploy
    parser.add_argument(
        '--service',
        action='store',
        required=True,
        help='Service to Deploy',
    )
    # UPF tag to deploy
    parser.add_argument(
        '--upf_tag',
        action='store',
        default='develop',
        help='UPF tag to Deploy',
    )
    # Docker-compose file to use
    parser.add_argument(
        '--docker_compose',
        action='store',
        default='docker-compose.yml',
        help='Docker-compose file to use (default: docker-compose.yml)',
    )
    # Mode
    parser.add_argument(
        '--mode',
        action='store',
        required=True,
        choices=['Deploy', 'Check', 'UnDeploy'],
        help='Mode',
    )
    return parser.parse_args()

def deployObject(service, tag):
    logging.info ('Deploying ' + service)
    os.chdir('docker-compose')
    subprocess_run_w_echo ('ls')

def subprocess_run_w_echo(cmd):
    logging.debug(cmd)
    subprocess.run(cmd, shell=True)

if __name__ == '__main__':
    main()
